# pytest-ogsm
## ！！！如果安装了pytest-html这个插件，请先卸载，不然会有冲突！！！

## 1、插件介绍
### 针对特定项目定制化插件，优化了pytest报告展示方式，运行用例时可以自定义参数
```
--report=report.html # 指定报告名
--title=指定报告标题
--tester=指定报告的测试人员
--desc=指定报告中的项目描述
可以同时使用多个参数
```

## 2、安装
本项目基于python3.9开发，需确认你的Python≥3.9

安装命令

`
pip install pytest-ogsm-plugin
`

## 3、其他
